pub fn decode_message<P: Protocol>(
source: &[u8],
limits: &Limits,
) -> Result<DecodedMessage<P::Message>, DecodeError>Expand description
Validates the common envelope, bounds, and schema before decoding a payload.
pub fn decode_message<P: Protocol>(
source: &[u8],
limits: &Limits,
) -> Result<DecodedMessage<P::Message>, DecodeError>Validates the common envelope, bounds, and schema before decoding a payload.