pub struct DecodeContext<'a> { /* private fields */ }Expand description
Stateful resource budget shared by one complete protocol decode.
Implementations
Sourceimpl<'a> DecodeContext<'a>
impl<'a> DecodeContext<'a>
Sourcepub fn claim_records(&mut self, count: u32) -> Result<(), DecodeError>
pub fn claim_records(&mut self, count: u32) -> Result<(), DecodeError>
Charges records against the aggregate budget before constructing them.
Sourcepub fn claim_allocation(&mut self, bytes: u32) -> Result<(), DecodeError>
pub fn claim_allocation(&mut self, bytes: u32) -> Result<(), DecodeError>
Charges bytes against the aggregate allocation budget before allocation.
Sourcepub fn copy_bytes(&mut self, source: &[u8]) -> Result<Vec<u8>, DecodeError>
pub fn copy_bytes(&mut self, source: &[u8]) -> Result<Vec<u8>, DecodeError>
Charges and copies hostile bytes into owned storage.