Audited conversion from native mapping witnesses to atomic capabilities.
Structs
- Reader
Region - Mapping-lifetime owner that can mint acquire-only capabilities.
- Writer
Region - Mapping-lifetime owner that prevents duplicate safe writer binding.
Enums
- Binding
Error - Failure to bind a validated layout to its native mapping witness.
Traits
- Read
Only Mapping - Native read-only mapping witness consumed by the audited binding boundary.
- Sole
Writer Mapping - Native sole-writer mapping witness consumed by the audited binding boundary.