pub struct AcknowledgementWriter<'a> { /* private fields */ }Expand description
Release-store capability for a cell in a writable mapping.
Implementations
Sourceimpl<'a> AcknowledgementWriter<'a>
impl<'a> AcknowledgementWriter<'a>
Sourcepub unsafe fn bind(
cell: &'a AcknowledgementCell,
binding: AcknowledgementWriterBinding,
) -> Self
pub unsafe fn bind( cell: &'a AcknowledgementCell, binding: AcknowledgementWriterBinding, ) -> Self
Binds a cell reached through its owner’s writable mapping.
Safety
cell must be the checked route cell described by binding; this
process must be the only writer of its containing mapping. No other
writer capability may be bound for this route while this value exists.
Sourcepub fn acknowledge(
&mut self,
observation: SlotObservation,
) -> Result<(), AcknowledgementError>
pub fn acknowledge( &mut self, observation: SlotObservation, ) -> Result<(), AcknowledgementError>
Acknowledges an exact observed slot identity with Release ordering.