pub unsafe trait ReadOnlyMapping {
// Required methods
fn base(&self) -> NonNull<u8>;
fn len(&self) -> usize;
// Provided method
fn is_empty(&self) -> bool { ... }
}Expand description
Native read-only mapping witness consumed by the audited binding boundary.
Safety
The base and length must describe one live, initialized allocation for the
witness lifetime. It must be OS-enforced read-only locally, cover exactly
the bytes used to create the supplied ValidatedRegionLayout, and remain
mapped while a bound region owns the witness.
Required Methods
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".